# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# NOTE! THIS FILE IS AUTOMATICALLY GENERATED AND WILL BE OVERWRITTEN!
#
# IF YOU WANT TO MODIFY THIS FILE, YOU SHOULD MODIFY THE TEMPLATE
# `get_provider_info_TEMPLATE.py.jinja2` IN the `dev/breeze/src/airflow_breeze/templates` DIRECTORY


def get_provider_info():
    return {
        "package-name": "apache-airflow-providers-mongo",
        "name": "MongoDB",
        "description": "`MongoDB <https://www.mongodb.com/>`__\n",
        "integrations": [
            {
                "integration-name": "MongoDB",
                "external-doc-url": "https://www.mongodb.com/",
                "logo": "/docs/integration-logos/MongoDB.png",
                "tags": ["software"],
            }
        ],
        "sensors": [
            {"integration-name": "MongoDB", "python-modules": ["airflow.providers.mongo.sensors.mongo"]}
        ],
        "hooks": [{"integration-name": "MongoDB", "python-modules": ["airflow.providers.mongo.hooks.mongo"]}],
        "connection-types": [
            {
                "hook-class-name": "airflow.providers.mongo.hooks.mongo.MongoHook",
                "connection-type": "mongo",
                "conn-fields": {
                    "srv": {"label": "Srv", "schema": {"type": ["boolean", "null"]}},
                    "ssl": {"label": "Ssl", "schema": {"type": ["boolean", "null"]}},
                    "allow_insecure": {"label": "Allow Insecure", "schema": {"type": ["boolean", "null"]}},
                },
                "ui-field-behaviour": {
                    "relabeling": {"login": "Username", "schema": "Default DB"},
                    "placeholders": {"port": "Note: port should not be set for SRV connections"},
                },
            }
        ],
    }
